# @(#) eloqwebd2.app - B.08.30 ($Revision: 28.14 $)
#
# The purpose of this file is to configure the applications
# the eloqwebd2 server can start.
# It is installed in the location:
# /etc/opt/eloquence/8.3/eloqwebd2.app
#
# This file is read at eloqwebd2 startup.
# Changes are automatically detected and honored.
#
# Format:
#
# The section names are not case sensitive. String values can be
# enclosed in double quotes to protect leading or trailing spaces.
# Everything after a hash (#) character is considered a comment.
#
# Each application definition is a separate section. The section
# header in square brackets specifies the application identifier
# (app_id) used in the HTML document which invokes the application.
#
# A [default] section may be specified to define configuration items
# which are common to all applications.
#
# The following configuration items are recognized for each section:
#
# [app_id]
#
# Title     Specifies the application display title. If not configured,
#           the application identifier (app_id) is used.
#
# Server    Specifies the address to connect the eloqsd server which
#           is used to start the application.
#
#           A host name or IP address may be specified, optionally
#           followed by a colon and a service name or port number.
#           An IPv6 address must be specified in square brackets.
#
#           The default is: localhost:eloqsd
#
#           For example:
#              hcluster2-eloq.foo.com:8100
#              192.168.22.33:eloqsd
#              [fe80::225:b3ff:fecf:362]:8100
#
# TLS       If nonzero, the eloqsd and DLG communication is secured
#           with TLS-encryption. This requires that the eloqsd server
#           is configured for TLS-encrypted communication.
#
# Command   Specifies the command line to start the application.
#
#           Command line arguments are separated with spaces. If an
#           argument contains space characters it must be enclosed
#           in single or double quotes.
#
#           Token resolving:
#
#           $remoteaddr - client (web browser) IP address
#           $remotename - client (web browser) host name
#           $remoteport - client (web browser) TCP port number
#           $login      - eloqsd login used to start the application
#
#           $(VARIABLENAME) - value of an environment variable,
#           including any variable specified with the Environment
#           configuration and any application argument passed as
#           environment variable (see below).
#
#           Multiple Command entries are recognized. The command
#           line is formed by concatenating the Command entries
#           in the specified order.
#
# Login     Specifies the eloqsd server login required to start
#           the application. Token resolving is applied as explained
#           in the Command section above. If not configured, login
#           credentials are requested by the client (web browser).
#
# Password  Specifies the eloqsd server password required to start
#           the application. This is not used if Login is not set.
#           Token resolving is applied as explained in the Command
#           section above. If not configured, login credentials are
#           requested by the client (web browser).
#
# LoginDomain  Specifies an optional string used to mark related
#           applications where a successful interactive login is
#           cached (see LoginCacheMax and LoginCacheTimeout in the
#           eloqwebd2.cfg configuration file).
#
#           The interactive login dialog contains a Save Login option
#           which is checked by default when the application has a
#           non-empty LoginDomain configured. When this option is
#           checked and the user logs in, the login name and password
#           are cached for this LoginDomain (if set) and server address.
#
#           The default is: not set (LoginDomain not specified)
#
# StartDir  Used to set the current directory where an application
#           is started. Token resolving is applied as explained in
#           the Command section above.
#
#           The default is: not set (start directory unspecified)
#
# Environment  Specifies an environment variable to be passed to
#           the application. Token resolving is applied as explained
#           in the Command section above.
#           Multiple Environment entries are recognized and combined.
#
# ArgEnvAccept
# ArgAtomAccept  Comma- or space-separated list specifying which
#           URL query string arguments are accepted to be passed
#           to the application.
#
#           ArgEnvAccept lists the argument names which are allowed
#           to be passed as environment variables.
#
#           ArgAtomAccept lists the argument names which are allowed
#           to be passed as atoms in the System object.
#
#           Please note that the argument name comparison is case
#           sensitive.
#
# ArgEnvPrefix
# ArgAtomPrefix  Allows to specify a name prefix for any argument
#           passed to the application.
#
#           ArgEnvPrefix specifies a prefix for arguments passed as
#           environment variables.
#
#           ArgAtomPrefix specifies a prefix for arguments passed as
#           atoms in the System object.
#
# DlgIdleTimeout  Specifies the maximum time in seconds an application
#           may be idle. The application is terminated if it does not
#           get any user input for longer than the specified time.
#           If set to zero the application never times out.
#           The default is: 3600 (60 minutes)
#
# Driver    Specifies the driver type reported to the program.
#           The default is: WEB2
#
# Locale    Specifies the application locale which defines international
#           settings such as numeric and date formats. If not set, the
#           user's browser locale ist used.
#
#           To set a specific application locale, an IETF BCP 47 language
#           tag must be used, for example:
#              en-US - English (United States)
#              en-GB - English (United Kingdom)
#              fr-FR - French (France)
#              de-DE - German (Germany)
#
#           The default is: not set (use browser locale)
#
# DefaultFontFace  Specifies the Dialog default font family name.
# DefaultFontSize  Specifies the Dialog default font size in point units.
#
#           These default font properties are used if a Dialog does not
#           have the fontface/fontsize/fontstyle attributes set.
#           The Dialog raster calculation is based on the Dialog font.
#
#           DefaultFontSize allows to specify a unit, for example: 16px
#           If no unit is specified, pt is assumed.
#
#           The default is: not set (use browser font)
#
# FontSizeFactor  Factor to increase or reduce the Dialog and object
#           font sizes (decimal number, for example 0.9 to reduce to
#           90% of the font size set for a Dialog or object).
#
#           This might help to adjust the Dialog appearance for
#           applications originally written for JDLG because the
#           browser might render certain fonts differently than
#           Java. For example, Java might render a font with 12pt
#           size although an object has fontsize=13 set, while
#           the browser renders the font with 13pt size. In such
#           a case, setting FontSizeFactor=0.923 will reduce the
#           font size from 13pt to 12pt, to achieve a similar
#           Dialog appearance in the browser.
#
#           Please note: This factor is not applied to calculate
#           the Dialog raster.
#
#           The default is: not set (use font sizes as specified)
#
# IgnoreDialogFont  If set to a nonzero value, any Dialog font attributes
#           set by the application are ignored, instead the default font
#           is used (see above). If the default font is not configured
#           the browser font is used.
#
#           This might help to achieve a unified Dialog appearance
#           for applications originally written for JDLG, by using
#           the same font attributes for all Dialogs even if different
#           Dialog font attributes are set.
#
#           Please note: This only applies to the Dialog font attributes,
#           child objects are not affected.
#
#           The default is: 0 (use Dialog font attributes as specified)
#
# BaseURL   Specifies the global base URL.
#
# HelpBaseURL  Specifies the global base URL for the help system.
#
# LogoIcon  URL to specify the application logo/icon. If a relative
#           URL is set, the global or application-specific base URL
#           is prepended. If not set, the Eloquence icon is used.
#
#           The default is: not set (use Eloquence icon)
#
# Atom.NAME Sets an atom named NAME in the System object. Token resolving
#           is applied as explained in the Command section above.
#
# Layout    Specifies how Dialogs are displayed. Supported modes are:
#
#           Layout = dialog
#
#                  Dialog windows are used. All visible Dialogs are
#                  displayed, the active Dialog is topmost.
#
#           Layout = inline
#
#                  The active Dialog is displayed inline in the HTML
#                  document at the top/left position in the Dialog
#                  container element. No other Dialogs are displayed.
#
#           Layout = inline max
#
#                  The inline Dialog is maximized so that it covers
#                  the entire container element.
#
#           Layout = inline dialog
#           Layout = inline max dialog
#
#                  If multiple Dialogs are visible, Dialog windows
#                  are used except for the Dialog at the bottom which
#                  is displayed inline (and maximized if the 'max'
#                  keyword is specified).
#
#           The default is: dialog
#
#           Please note that individual Dialogs can override the
#           specified layout mode:
#
#           1) A Dialog is always inline if the x/y/w/h attributes
#              are not set, or if they are all set to zero.
#
#           2) A Dialog is always inline if the xauto/yauto attributes
#              are set to a value other than 1.
#              The xauto/yauto modes 0 and -1 may be used if the Dialog
#              position in the container element should be different
#              from top/left.
#
# TypeAhead  If set to a nonzero value, the typeahead function is
#           enabled. The typeahead function prevents characters from
#           being lost if they are typed while the Dialog is not
#           interactive, i.e., currently outside DLG DO.
#
#           The default is: 1 (typeahead function enabled)
#
# StrictMode  If set to a nonzero value, strict attribute value checking
#           is enabled. By default, JDLG behavior is applied where setting
#           attribute values is loosely checked. For example, setting the
#           ListBox.topitem attribute out-of-range is accepted by JDLG
#           but results in DLG STATUS 660 if StrictMode is set.
#
#           The default is: 0 (JDLG-compatible value checking enabled)
#
# PopupPosition  Specifies the position of popup windows (login dialog,
#           message dialog, POPUP BOX). The position is specified by the
#           top/left/center keywords which may be combined, separated
#           with a space character, for example:
#              top left   - vertical top and horizontal left position
#              top center - vertical top position, horizontally centered
#              top        - same as above
#           Optionally, the popup dialog type may be specified if not all
#           types should be affected. Possible types (may be combined):
#              login   - login dialog
#              message - message dialog
#              box     - POPUP BOX
#           For example, if the login and messages dialog should be displayed
#           at the vertical top position and horizontally centered, but the
#           POPUP BOX should use the default (centered both horizontally and
#           vertically):
#              login message top
#
#           The default is: center (all popup dialog types centered both
#           horizontally and vertically)
#
# ShowStartErrors  If set to a nonzero value, a possible application start
#           error message (for example 'authorization failed: bad password')
#           is displayed to the user. This can be disabled by setting
#           ShowStartErrors to zero.
#
#           The default is: 1 (error messages are displayed)


# The example configuration below starts the EXAMPLE,APP program, using
# the local eloqsd server interactively requesting the login credentials.
# It expires if there is no user input for more than 10 minutes.

#[EXAMPLE]
#Command = EXAMPLE,APP
#Environment = HOME=/home/$login
#DlgIdleTimeout = 600

